============
Installation
============

At the command line::

    $ easy_install pyramid_transactional_celery

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pyramid_transactional_celery
    $ pip install pyramid_transactional_celery
